package examples.mqe_configuration_guide;
/*------------------------------------------------------------------------------*/ 
/*                      MQSeries Everyplace for Multiplatforms                  */ 
/*                                                                              */                                                        
/*                                                                              */ 
/* 5765-E63                                                                     */ 
/* (C) Copyright IBM Corp. 1999 - 2002                                          */ 
/*                                                                              */ 
/*                                                                              */ 
/*------------------------------------------------------------------------------*/ 
import com.ibm.mqe.*;
import com.ibm.mqe.administration.*;
import com.ibm.mqe.mqbridge.*;
import examples.queuemanager.*;
import java.util.*;
import java.io.*;

//
//This class contains the examples in the MQSeries Everyplace for Multiplatforms
//Configuration Guide SupportPac
//

public class MQeConfigGuide
{		
	MQeChannelListener			localChannelListener;							//local client/server channel listener
	MQeMQBridges				localBridges;									//local bridges object
	
	//
	//main method - execute example with the command: jview examples.mqe_configuration_guide.MQeConfigGuide n
	//
	//		Note:	For non-windows systems substitute the string 'jview' with the appropriate JVM command
	//				Select 'n' as instructed in the accompanying manual
	//
	public static void main( String args[] )
	{
        try 
		{
			//get example number to run
			int example = 0;
			if (args != null && args.length > 0)			
				example = Integer.parseInt(args[0].trim());
		
			//create instance of MQeConfigGuide
			MQeConfigGuide me = new MQeConfigGuide();
		
			//run example
			switch (example)
			{
				case 1:	//run the client queue manager myClientQMgr 	
						System.out.println(
							"Example 1: Running the client queue manager - myClientQMgr");		
						me.startClientQMgr();
						me.stopClientQMgr();
						break;
						
				case 2:	//create and then run the client queue manager myClientQMgr 	
						System.out.println(
							"Example 2: Creating the client queue manager - myClientQMgr");		
						me.createClientQMgr();
						me.startClientQMgr();
						me.stopClientQMgr();
						break;
						
				case 3:	//inquire on the client queue manager myClientQMgr 	
						System.out.println(
							"Example 3: Inquiring on the queue manager - myClientQMgr");		
						me.startClientQMgr();
						me.inquireClientQMgr();
						me.stopClientQMgr();
						break;
						
				case 4:	//set a property on the client queue manager myClientQMgr 	
						System.out.println(
							"Example 4: Setting a property on the queue manager - myClientQMgr");		
						me.startClientQMgr();
						me.setPropertyClientQMgr();
						me.stopClientQMgr();
						break;
						
				case 5:	//create a direct connection on the client queue manager myClientQMgr 	
						System.out.println(
							"Example 5: Creating a direct connection on the queue manager - myClientQMgr");		
						me.startClientQMgr();
						me.createDirectConnection();
						me.stopClientQMgr();
						break;
						
				case 6:	//create an indirect connection on the client queue manager myClientQMgr 	
						System.out.println(
							"Example 6: Creating an indirect connection on the queue manager - myClientQMgr");		
						me.startClientQMgr();
						me.createIndirectConnection();
						me.stopClientQMgr();
						break;
						
				case 7:	//create a peer listener on the client queue manager myClientQMgr 	
						System.out.println(
							"Example 7: Creating a peer listener on the queue manager - myClientQMgr");		
						me.startClientQMgr();
						me.createPeerListener();
						me.stopClientQMgr();
						break;
				
				case 8:	//run the server queue manager myServerQMgr 	
						System.out.println(
							"Example 8: Running the server queue manager - myServerQMgr");		
						me.startServerQMgr();
						me.stopServerQMgr();
						break;
						
				case 9:	//run the gateway queue manager myGatewayQMgr 	
						System.out.println(
							"Example 9: Running the gateway queue manager - myGatewayQMgr");		
						me.startGatewayQMgr();
						me.stopGatewayQMgr();
						break;
						
				case 10://run the peer queue manager myPeerQMgr 	
						System.out.println(
							"Example 10: Running the peer queue manager - myPeerQMgr");		
						me.startPeerQMgr();
						me.stopPeerQMgr();
						break;
				
				default://no more cases
						System.out.println(
							"Invalid example number");	
			}
        }
		
		//catch any exceptions
		catch ( Exception e )
		{
			System.out.println("Errors detected:");
			e.printStackTrace();
        }
		
		//finished
        System.exit(0);
    }
	
	//
	//create the environmental parameters for the myClientQMgr 
	//
	private MQeFields createClientEnvironment() throws Exception
	{
		//create [Registry] section
		MQeFields registry = new MQeFields();
		registry.putAscii("DirName", "C:\\Program Files\\MQe\\Java\\mqe_explorer\\myClientQMgr\\Registry\\");
		registry.putAscii("LocalRegType", "com.ibm.mqe.registry.MQeFileSession");
		registry.putAscii("Adapter", "com.ibm.mqe.adapters.MQeDiskFieldsAdapter");
		
		//create [QueueManager] section
		MQeFields queueManager = new MQeFields();
		queueManager.putAscii("Name", "myClientQMgr");
		
		//create [Alias] section
		MQeFields alias = new MQeFields();
		alias.putAscii("Admin", "examples.administration.console.Admin");
		alias.putAscii("RegistryAdapter", "com.ibm.mqe.adapters.MQeDiskFieldsAdapter");
		alias.putAscii("DefaultTransporter", "com.ibm.mqe.MQeTransporter");
		alias.putAscii("MsgLog", "com.ibm.mqe.adapters.MQeDiskFieldsAdapter");
		alias.putAscii("EventLog", "examples.eventlog.LogToDiskFile");
		alias.putAscii("QueueManager", "com.ibm.mqe.MQeQueueManager");
		alias.putAscii("Server", "examples.queuemanager.MQeServer");
		alias.putAscii("PrivateRegistry", "com.ibm.mqe.registry.MQePrivateSession");
		alias.putAscii("MQBridge", "com.ibm.mqe.mqbridge.MQeMQBridges");
		alias.putAscii("DefaultChannel", "com.ibm.mqe.MQeChannel");
		alias.putAscii("Network", "com.ibm.mqe.adapters.MQeTcpipHttpAdapter");
		alias.putAscii("FastNetwork", "com.ibm.mqe.adapters.MQeTcpipHistoryAdapter");
		alias.putAscii("ChannelAttrRules", "examples.rules.AttributeRule");
		alias.putAscii("AttributeKey_2", "com.ibm.mqe.attributes.MQeSharedKey");
		alias.putAscii("AttributeKey_1", "com.ibm.mqe.MQeKey");
		alias.putAscii("FileRegistry", "com.ibm.mqe.registry.MQeFileSession");
		alias.putAscii("Permission", "examples.security.MQeSecurity");
					   
		//create [PreLoad] section
		//not needed for myClientQMgr
		
		//create [Permission] section
		//not needed for myClientQMgr
		
		//add sections to environment
		MQeFields environment = new MQeFields();
		environment.putFields("Registry", registry);
		environment.putFields("QueueManager", queueManager);
		environment.putFields("Alias", alias);
		
		//return
		return (environment);
	}
	
	//
	//creates a configured client queue manager 
	//environmental parameters loaded from a .ini file (or programatically if source edited)
	//
	private void createClientQMgr() throws Exception
	{
		//initialize strings
		String filename =
			"C:\\Program Files\\MQe\\Java\\mqe_explorer\\myClientQMgr.ini";		//file path
		String queueDirectory =
			"C:\\Program Files\\MQe\\Java\\MQe_Explorer\\myClientQMgr\\Queues";	//queue path
		
		//load .ini file into MQeFields object
		MQeFields environment = MQeQueueManagerUtils.loadConfigFile(filename);
		
		//create environment prgrammatically
		//environment = createClientEnvironment();
		
		//make the queue directory
		File qFile = new File(queueDirectory);
		qFile.mkdirs();

		//set the details for default queue storage
		String msgStore = "com.ibm.mqe.messagestore.MQeMessageStore";
		String queueAdapter = "com.ibm.mqe.adapters.MQeDiskFieldsAdapter";
		String queueStorage = msgStore + ":"  + queueAdapter + ":" + queueDirectory;

		//create a queue manager configurator
		MQeQueueManagerConfigure qMgrConfig =
			new MQeQueueManagerConfigure(environment, queueStorage);

		//set queue manager properties
		qMgrConfig.setDescription("My queue manager");
		qMgrConfig.setChnlAttributeRuleName("examples.rules.AttributeRule");
		qMgrConfig.setQMgrRuleName("com.ibm.mqe.MQeQueueManagerRule");

		//create the queue manager
		qMgrConfig.defineQueueManager();

		//create default queues
		qMgrConfig.defineDefaultAdminQueue();									//AdminQ
		qMgrConfig.defineDefaultDeadLetterQueue();								//DeadLetterQ
		qMgrConfig.defineDefaultSystemQueue();									//SYSTEM.DEFAULT.....
		qMgrConfig.defineDefaultAdminReplyQueue();								//AdminReplyQ

		//close the configurator
		qMgrConfig.close();
		
		//inform that configuration is complete
		System.out.println("Queue manager configuration completed");
	}
	
	//
	//creates a direct connection
	//
	private void createDirectConnection() throws Exception
	{
		//get addressability to the local queue manager
		MQeQueueManager qMgr = MQeQueueManager.getReference(null);

		//set up strings
		String thisQMgrName = qMgr.getName();									//local qMgr name
		String targetQMgrName = "myClientQMgr";									//target qMgr name
		String connName = "myServerQMgr";										//connection name
		String descrText = "Direct connection to myServerQMgr";					//description
		String adapterText = "com.ibm.mqe.adapters.MQeTcpipHistoryAdapter";		//adapter class
		String portText = "8082";												//IP port
		String addressText = "127.0.0.1";										//IP address
		String channelText = "com.ibm.mqe.MQeChannel";							//channel class
		String optionsText = "<PERSIST><HISTORY>";								//adapter options
		String parmsText = "";													//adapter parameters

		//create the basic connection admin message
		MQeConnectionAdminMsg adminMsg = new MQeConnectionAdminMsg();

		//add command-neutral elements
		adminMsg.putAscii(MQeAdminMsg.Admin_TargetQMgr, targetQMgrName);		//set target qMgr
		adminMsg.putInt(MQeAdminMsg.Admin_MaxAttempts, 1);						//set max tries
		adminMsg.putInt(MQe.Msg_Style, MQe.Msg_Style_Request);					//need a reply
		adminMsg.putAscii(MQe.Msg_ReplyToQMgr, thisQMgrName);					//reply queue manager
		adminMsg.putAscii(MQe.Msg_ReplyToQ, MQe.Admin_Reply_Queue_Name);		//reply queue

		//add unique reference
		byte[] adminKey = MQe.longToByte(System.currentTimeMillis());			//generate unique key
		adminMsg.putArrayOfByte(MQe.Msg_CorrelID, adminKey);					//add key

		//add create command
		adminMsg.putInt(MQeAdminMsg.Admin_Action, MQeAdminMsg.Action_Create);

		//add command parameters
		MQeFields parms = new MQeFields();										//new parms object
		parms.putAscii(MQeAdminMsg.Admin_Name, connName);						//connection name
		parms.putAscii(MQeAdminMsg.Admin_Class,
				"com.ibm.mqe.MQeConnectionDefinition");							//object class
		parms.putUnicode(MQeConnectionAdminMsg.Con_Description,
				descrText);														//description
		parms.putAscii(MQeConnectionAdminMsg.Con_Channel,
				channelText);													//channel class
		MQeFields[] adapterArray = new MQeFields[1];							//adapter array
		adapterArray[0] = new MQeFields();										//primary member
		adapterArray[0].putAscii(MQeConnectionAdminMsg.Con_Adapter,
				adapterText + ":" + addressText + ":" + portText);				//file descriptor
		adapterArray[0].putAscii(MQeConnectionAdminMsg.Con_AdapterOptions,
				optionsText);													//options
		adapterArray[0].putAscii(MQeConnectionAdminMsg.Con_AdapterAsciiParm,
				parmsText);														//parameters
		parms.putFieldsArray(MQeConnectionAdminMsg.Con_Adapters,
				adapterArray);													//adapter array
		adminMsg.putFields(MQeAdminMsg.Admin_Parms, parms);						//add parms

		//send admin message
		qMgr.putMessage(targetQMgrName, MQe.Admin_Queue_Name, adminMsg , null, 0);
		
		//inform that admin message sent
		System.out.println("Connection creation admin message sent");
		
		//getting the reply
		
		//create a filter
		MQeFields msgFilter = new MQeFields();									//new filter
		msgFilter.putArrayOfByte(MQe.Msg_CorrelID, adminKey);					//add key

		//wait for reply
		int waitTime = 10000;													//wait 10 secs
		MQeAdminMsg adminReply = (MQeAdminMsg) qMgr.waitForMessage(thisQMgrName,
			MQe.Admin_Reply_Queue_Name, msgFilter, null, 0, waitTime);			//get reply
		
		//inform that reply received
		if (adminReply != null) System.out.println("Reply received");
		
		//report on success
		byte returnCode = adminReply.getByte(MQeAdminMsg.Admin_RC);
		if (returnCode == MQeAdminMsg.RC_Success)
			System.out.println("Success");
		else System.out.println("Errors occured");
	}
	
	//
	//creates an indirect connection
	//
	private void createIndirectConnection() throws Exception
	{
		//get addressability to the local queue manager
		MQeQueueManager qMgr = MQeQueueManager.getReference(null);

		//set up strings
		String thisQMgrName = qMgr.getName();									//local qMgr name
		String targetQMgrName = "myClientQMgr";									//target qMgr name
		String connName = "myOtherQMgr";										//connection name
		String viaName = "myServerQMgr";										//via qMgr name
		String channelText = "com.ibm.mqe.MQeChannel";							//channel class
		String descrText = 
				"Indirect connection to myOtherQmgr via myServerQM";			//description

		//create the basic connection admin message
		MQeConnectionAdminMsg adminMsg = new MQeConnectionAdminMsg();

		//add command-neutral elements
		adminMsg.putAscii(MQeAdminMsg.Admin_TargetQMgr, targetQMgrName);		//set target qMgr
		adminMsg.putInt(MQeAdminMsg.Admin_MaxAttempts, 1);						//set max tries
		adminMsg.putInt(MQe.Msg_Style, MQe.Msg_Style_Request);					//need a reply
		adminMsg.putAscii(MQe.Msg_ReplyToQMgr, thisQMgrName);					//reply queue manager
		adminMsg.putAscii(MQe.Msg_ReplyToQ, MQe.Admin_Reply_Queue_Name);		//reply queue

		//add unique reference
		byte[] adminKey = MQe.longToByte(System.currentTimeMillis());			//generate unique key
		adminMsg.putArrayOfByte(MQe.Msg_CorrelID, adminKey);					//add key

		//add create command
		adminMsg.putInt(MQeAdminMsg.Admin_Action, MQeAdminMsg.Action_Create);

		//add command parameters
		MQeFields parms = new MQeFields();										//new parms object
		parms.putAscii(MQeAdminMsg.Admin_Name, connName);						//connection name
		parms.putAscii(MQeAdminMsg.Admin_Class,
				"com.ibm.mqe.MQeConnectionDefinition");							//object class
		parms.putUnicode(MQeConnectionAdminMsg.Con_Description,
				descrText);														//description
		parms.putAscii(MQeConnectionAdminMsg.Con_Channel,
				channelText);													//channel class
		MQeFields[] adapterArray = new MQeFields[1];							//adapter array
		adapterArray[0] = new MQeFields();										//primary member
		adapterArray[0].putAscii(MQeConnectionAdminMsg.Con_Adapter,
				viaName);														//file descriptor
		parms.putFieldsArray(MQeConnectionAdminMsg.Con_Adapters,
				adapterArray);													//adapter array
		adminMsg.putFields(MQeAdminMsg.Admin_Parms, parms);						//add parms

		//send admin message
		qMgr.putMessage(targetQMgrName, MQe.Admin_Queue_Name, adminMsg , null, 0);

		
		//inform that admin message sent
		System.out.println("Connection creation admin message sent");
		
		//getting the reply
		
		//create a filter
		MQeFields msgFilter = new MQeFields();									//new filter
		msgFilter.putArrayOfByte(MQe.Msg_CorrelID, adminKey);					//add key

		//wait for reply
		int waitTime = 10000;													//wait 10 secs
		MQeAdminMsg adminReply = (MQeAdminMsg) qMgr.waitForMessage(thisQMgrName,
			MQe.Admin_Reply_Queue_Name, msgFilter, null, 0, waitTime);			//get reply
		
		//inform that reply received
		if (adminReply != null) System.out.println("Reply received");
		
		//report on success
		byte returnCode = adminReply.getByte(MQeAdminMsg.Admin_RC);
		if (returnCode == MQeAdminMsg.RC_Success)
			System.out.println("Success");
		else System.out.println("Errors occured");
	}
	
	//
	//create the environmental parameters for the myGatewayQMgr 
	//
	private MQeFields createGatewayEnvironment() throws Exception
	{
		//create [Registry] section
		MQeFields registry = new MQeFields();
		registry.putAscii("DirName", "C:\\Program Files\\MQe\\Java\\mqe_explorer\\myGatewayQMgr\\Registry\\");
		registry.putAscii("LocalRegType", "com.ibm.mqe.registry.MQeFileSession");
		registry.putAscii("Adapter", "com.ibm.mqe.adapters.MQeDiskFieldsAdapter");
		
		//create [QueueManager] section
		MQeFields queueManager = new MQeFields();
		queueManager.putAscii("Name", "myGatewayQMgr");
		
		//create [Alias] section
		MQeFields alias = new MQeFields();
		alias.putAscii("Admin", "examples.administration.console.Admin");
		alias.putAscii("RegistryAdapter", "com.ibm.mqe.adapters.MQeDiskFieldsAdapter");
		alias.putAscii("DefaultTransporter", "com.ibm.mqe.MQeTransporter");
		alias.putAscii("MsgLog", "com.ibm.mqe.adapters.MQeDiskFieldsAdapter");
		alias.putAscii("EventLog", "examples.eventlog.LogToDiskFile");
		alias.putAscii("QueueManager", "com.ibm.mqe.MQeQueueManager");
		alias.putAscii("Server", "examples.queuemanager.MQeServer");
		alias.putAscii("PrivateRegistry", "com.ibm.mqe.registry.MQePrivateSession");
		alias.putAscii("MQBridge", "com.ibm.mqe.mqbridge.MQeMQBridges");
		alias.putAscii("DefaultChannel", "com.ibm.mqe.MQeChannel");
		alias.putAscii("Network", "com.ibm.mqe.adapters.MQeTcpipHttpAdapter");
		alias.putAscii("FastNetwork", "com.ibm.mqe.adapters.MQeTcpipHistoryAdapter");
		alias.putAscii("ChannelAttrRules", "examples.rules.AttributeRule");
		alias.putAscii("AttributeKey_2", "com.ibm.mqe.attributes.MQeSharedKey");
		alias.putAscii("AttributeKey_1", "com.ibm.mqe.MQeKey");
		alias.putAscii("FileRegistry", "com.ibm.mqe.registry.MQeFileSession");
		alias.putAscii("Permission", "examples.security.MQeSecurity");
		
		//create [Listener] section
		MQeFields listener = new MQeFields();
		listener.putAscii("Network", "com.ibm.mqe.adapters.MQeTcpipHistoryAdapter:");
		listener.putAscii("Listen", "com.ibm.mqe.adapters.MQeTcpipHistoryAdapter::8082");
		listener.putInt("TimeInterval", 300);
		
		//create [ChannelManager] section
		MQeFields channelManager = new MQeFields();
		channelManager.putInt("MaxChannels", 0);
		
		//create [MQBridge] section
		MQeFields mqBridge = new MQeFields();
		mqBridge.putAscii("MQLoadBridgeRule", "com.ibm.mqe.mqbridge.MQeLoadBridgeRule");
		
		//create [PreLoad] section
		//not needed for myGatewayQMgr
		
		//create [Permission] section
		//not needed for myGatewayQMgr
		
		//add sections to environment
		MQeFields environment = new MQeFields();
		environment.putFields("Registry", registry);
		environment.putFields("QueueManager", queueManager);
		environment.putFields("Alias", alias);
		environment.putFields("Listener", listener);
		environment.putFields("ChannelManager", channelManager);
		environment.putFields("MQBridge", mqBridge);
		
		//return
		return (environment);
	}
	
	//
	//create the environmental parameters for the myPeerQMgr 
	//
	private MQeFields createPeerEnvironment() throws Exception
	{
		//create [Registry] section
		MQeFields registry = new MQeFields();
		registry.putAscii("DirName", "C:\\Program Files\\MQe\\Java\\mqe_explorer\\myPeerQMgr\\Registry\\");
		registry.putAscii("LocalRegType", "com.ibm.mqe.registry.MQeFileSession");
		registry.putAscii("Adapter", "com.ibm.mqe.adapters.MQeDiskFieldsAdapter");
		
		//create [QueueManager] section
		MQeFields queueManager = new MQeFields();
		queueManager.putAscii("Name", "myPeerQMgr");
		
		//create [Alias] section
		MQeFields alias = new MQeFields();
		alias.putAscii("Admin", "examples.administration.console.Admin");
		alias.putAscii("RegistryAdapter", "com.ibm.mqe.adapters.MQeDiskFieldsAdapter");
		alias.putAscii("DefaultTransporter", "com.ibm.mqe.MQeTransporter");
		alias.putAscii("MsgLog", "com.ibm.mqe.adapters.MQeDiskFieldsAdapter");
		alias.putAscii("EventLog", "examples.eventlog.LogToDiskFile");
		alias.putAscii("QueueManager", "com.ibm.mqe.MQeQueueManager");
		alias.putAscii("Server", "examples.queuemanager.MQeServer");
		alias.putAscii("PrivateRegistry", "com.ibm.mqe.registry.MQePrivateSession");
		alias.putAscii("MQBridge", "com.ibm.mqe.mqbridge.MQeMQBridges");
		alias.putAscii("DefaultChannel", "com.ibm.mqe.MQeChannel");
		alias.putAscii("Network", "com.ibm.mqe.adapters.MQeTcpipHttpAdapter");
		alias.putAscii("FastNetwork", "com.ibm.mqe.adapters.MQeTcpipHistoryAdapter");
		alias.putAscii("ChannelAttrRules", "examples.rules.AttributeRule");
		alias.putAscii("AttributeKey_2", "com.ibm.mqe.attributes.MQeSharedKey");
		alias.putAscii("AttributeKey_1", "com.ibm.mqe.MQeKey");
		alias.putAscii("FileRegistry", "com.ibm.mqe.registry.MQeFileSession");
		alias.putAscii("Permission", "examples.security.MQeSecurity");
					   
		//create [PreLoad] section
		//not needed for myClientQMgr
		
		//create [Permission] section
		//not needed for myClientQMgr
		
		//add sections to environment
		MQeFields environment = new MQeFields();
		environment.putFields("Registry", registry);
		environment.putFields("QueueManager", queueManager);
		environment.putFields("Alias", alias);
		
		//return
		return (environment);
	}
	
	//
	//create the environmental parameters for the myServerQMgr 
	//
	private MQeFields createServerEnvironment() throws Exception
	{
		//create [Registry] section
		MQeFields registry = new MQeFields();
		registry.putAscii("DirName", "C:\\Program Files\\MQe\\Java\\mqe_explorer\\myServerQMgr\\Registry\\");
		registry.putAscii("LocalRegType", "com.ibm.mqe.registry.MQeFileSession");
		registry.putAscii("Adapter", "com.ibm.mqe.adapters.MQeDiskFieldsAdapter");
		
		//create [QueueManager] section
		MQeFields queueManager = new MQeFields();
		queueManager.putAscii("Name", "myServerQMgr");
		
		//create [Alias] section
		MQeFields alias = new MQeFields();
		alias.putAscii("Admin", "examples.administration.console.Admin");
		alias.putAscii("RegistryAdapter", "com.ibm.mqe.adapters.MQeDiskFieldsAdapter");
		alias.putAscii("DefaultTransporter", "com.ibm.mqe.MQeTransporter");
		alias.putAscii("MsgLog", "com.ibm.mqe.adapters.MQeDiskFieldsAdapter");
		alias.putAscii("EventLog", "examples.eventlog.LogToDiskFile");
		alias.putAscii("QueueManager", "com.ibm.mqe.MQeQueueManager");
		alias.putAscii("Server", "examples.queuemanager.MQeServer");
		alias.putAscii("PrivateRegistry", "com.ibm.mqe.registry.MQePrivateSession");
		alias.putAscii("MQBridge", "com.ibm.mqe.mqbridge.MQeMQBridges");
		alias.putAscii("DefaultChannel", "com.ibm.mqe.MQeChannel");
		alias.putAscii("Network", "com.ibm.mqe.adapters.MQeTcpipHttpAdapter");
		alias.putAscii("FastNetwork", "com.ibm.mqe.adapters.MQeTcpipHistoryAdapter");
		alias.putAscii("ChannelAttrRules", "examples.rules.AttributeRule");
		alias.putAscii("AttributeKey_2", "com.ibm.mqe.attributes.MQeSharedKey");
		alias.putAscii("AttributeKey_1", "com.ibm.mqe.MQeKey");
		alias.putAscii("FileRegistry", "com.ibm.mqe.registry.MQeFileSession");
		alias.putAscii("Permission", "examples.security.MQeSecurity");
		
		//create [Listener] section
		MQeFields listener = new MQeFields();
		listener.putAscii("Network", "com.ibm.mqe.adapters.MQeTcpipHistoryAdapter:");
		listener.putAscii("Listen", "com.ibm.mqe.adapters.MQeTcpipHistoryAdapter::8082");
		listener.putInt("TimeInterval", 300);
		
		//create [ChannelManager] section
		MQeFields channelManager = new MQeFields();
		channelManager.putInt("MaxChannels", 0);
		
		//create [PreLoad] section
		//not needed for myServerQMgr
		
		//create [Permission] section
		//not needed for myServerQMgr
		
		//add sections to environment
		MQeFields environment = new MQeFields();
		environment.putFields("Registry", registry);
		environment.putFields("QueueManager", queueManager);
		environment.putFields("Alias", alias);
		environment.putFields("Listener", listener);
		environment.putFields("ChannelManager", channelManager);
		
		//return
		return (environment);
	}
	
	//
	//creates a peer listener
	//
	private void createPeerListener() throws Exception
	{
		//get addressability to the local queue manager
		MQeQueueManager qMgr = MQeQueueManager.getReference(null);

		//set up strings
		String thisQMgrName = qMgr.getName();									//local qMgr name
		String targetQMgrName = "myClientQMgr";									//target qMgr name
		String descrText = "Peer listener on port 8084";						//description
		String adapterText = "com.ibm.mqe.adapters.MQeTcpipHistoryAdapter";		//adapter class
		String portText = "8084";												//IP port
		String channelText = "com.ibm.mqe.MQePeerChannel";						//channel class

		//create the basic connection admin message
		MQeConnectionAdminMsg adminMsg = new MQeConnectionAdminMsg();

		//add command-neutral elements
		adminMsg.putAscii(MQeAdminMsg.Admin_TargetQMgr, targetQMgrName);		//set target qMgr
		adminMsg.putInt(MQeAdminMsg.Admin_MaxAttempts, 1);						//set max tries
		adminMsg.putInt(MQe.Msg_Style, MQe.Msg_Style_Request);					//need a reply
		adminMsg.putAscii(MQe.Msg_ReplyToQMgr, thisQMgrName);					//reply queue manager
		adminMsg.putAscii(MQe.Msg_ReplyToQ, MQe.Admin_Reply_Queue_Name);		//reply queue

		//add unique reference
		byte[] adminKey = MQe.longToByte(System.currentTimeMillis());			//generate unique key
		adminMsg.putArrayOfByte(MQe.Msg_CorrelID, adminKey);					//add key

		//add create command
		adminMsg.putInt(MQeAdminMsg.Admin_Action, MQeAdminMsg.Action_Create);

		//add command parameters
		MQeFields parms = new MQeFields();										//new parms object
		parms.putAscii(MQeAdminMsg.Admin_Name, targetQMgrName );				//connection name
		parms.putAscii(MQeAdminMsg.Admin_Class,
				"com.ibm.mqe.MQeConnectionDefinition");							//object class
		parms.putUnicode(MQeConnectionAdminMsg.Con_Description,
				descrText);														//description
		parms.putAscii(MQeConnectionAdminMsg.Con_Channel,
				channelText);													//channel class
		MQeFields[] adapterArray = new MQeFields[1];							//adapter array
		adapterArray[0] = new MQeFields();										//primary member
		adapterArray[0].putAscii(MQeConnectionAdminMsg.Con_Adapter,
				adapterText + "::" + portText);									//file descriptor
		parms.putFieldsArray(MQeConnectionAdminMsg.Con_Adapters,
				adapterArray);													//adapter array
		adminMsg.putFields(MQeAdminMsg.Admin_Parms, parms);						//add parms

		//send admin message
		qMgr.putMessage(targetQMgrName, MQe.Admin_Queue_Name, adminMsg , null, 0);

		
		//inform that admin message sent
		System.out.println("Peer listener creation admin message sent");
		
		//getting the reply
		
		//create a filter
		MQeFields msgFilter = new MQeFields();									//new filter
		msgFilter.putArrayOfByte(MQe.Msg_CorrelID, adminKey);					//add key

		//wait for reply
		int waitTime = 10000;													//wait 10 secs
		MQeAdminMsg adminReply = (MQeAdminMsg) qMgr.waitForMessage(thisQMgrName,
			MQe.Admin_Reply_Queue_Name, msgFilter, null, 0, waitTime);			//get reply
		
		//inform that reply received
		if (adminReply != null) System.out.println("Reply received");
		
		//report on success
		byte returnCode = adminReply.getByte(MQeAdminMsg.Admin_RC);
		if (returnCode == MQeAdminMsg.RC_Success)
			System.out.println("Success");
		else System.out.println("Errors occured");
	}
	
	//
	//inquires on the myClientQMgr 
	//
	private void inquireClientQMgr() throws Exception
	{
		//get addressability to the local queue manager
		MQeQueueManager qMgr = MQeQueueManager.getReference(null);

		//set up strings
		String thisQMgrName = qMgr.getName();									//local qMgr name
		String targetQMgrName = "myClientQMgr";									//target qMgr name

		//create the basic queue manager admin message
		MQeQueueManagerAdminMsg adminMsg = new MQeQueueManagerAdminMsg();

		//add command-neutral elements
		adminMsg.putAscii(MQeAdminMsg.Admin_TargetQMgr, targetQMgrName);		//set target qMgr
		adminMsg.putInt(MQeAdminMsg.Admin_MaxAttempts, 1);						//set max tries
		adminMsg.putInt(MQe.Msg_Style, MQe.Msg_Style_Request);					//need a reply
		adminMsg.putAscii(MQe.Msg_ReplyToQMgr, thisQMgrName);					//reply queue manager
		adminMsg.putAscii(MQe.Msg_ReplyToQ, MQe.Admin_Reply_Queue_Name);		//reply queue

		//add unique reference
		byte[] adminKey = MQe.longToByte(System.currentTimeMillis());			//generate unique key
		adminMsg.putArrayOfByte(MQe.Msg_CorrelID, adminKey);					//add key

		//add inquiry command
		adminMsg.putInt(MQeAdminMsg.Admin_Action, MQeAdminMsg.Action_InquireAll);

		//add command parameters
		MQeFields parms = new MQeFields();										//new parms object
		parms.putAscii(MQeAdminMsg.Admin_Name, targetQMgrName);					//admin object
		adminMsg.putFields(MQeAdminMsg.Admin_Parms, parms);						//add parms

		//send admin message
		qMgr.putMessage(targetQMgrName, MQe.Admin_Queue_Name, adminMsg , null, 0);
		
		//inform that admin message sent
		System.out.println("Inquiry sent");
		
		//getting the reply
		
		//create a filter
		MQeFields msgFilter = new MQeFields();									//new filter
		msgFilter.putArrayOfByte(MQe.Msg_CorrelID, adminKey);					//add key

		//wait for reply
		int waitTime = 10000;													//wait 10 secs
		MQeAdminMsg adminReply = (MQeAdminMsg) qMgr.waitForMessage(thisQMgrName,
			MQe.Admin_Reply_Queue_Name, msgFilter, null, 0, waitTime);			//get reply
		
		//inform that reply received
		if (adminReply != null) System.out.println("Reply received");
		
		//extracting the information
		
		//extract the command parameters
		parms = adminReply.getFields(MQeAdminMsg.Admin_Parms);

		//extract each property
		String descr = parms.getUnicode(
				MQeQueueManagerAdminMsg.QMgr_Description);						//description
		long chTimeout = parms.getLong(
			MQeQueueManagerAdminMsg.QMgr_ChnlTimeout);							//channel timeout

		//report on properties
		System.out.println("Description = " + descr);
		System.out.println("Channel timeout = " + Long.toString(chTimeout));
	}
	
	//
	//sets the channel timeout on the myClientQMgr 
	//
	private void setPropertyClientQMgr() throws Exception
	{
		//get addressability to the local queue manager
		MQeQueueManager qMgr = MQeQueueManager.getReference(null);
		
		//set up strings
		String thisQMgrName = qMgr.getName();									//local qMgr name
		String targetQMgrName = "myClientQMgr";									//target qMgr name

		//create the basic queue manager admin message
		MQeQueueManagerAdminMsg adminMsg = new MQeQueueManagerAdminMsg();

		//add command-neutral elements
		adminMsg.putAscii(MQeAdminMsg.Admin_TargetQMgr, targetQMgrName);		//set target qMgr
		adminMsg.putInt(MQeAdminMsg.Admin_MaxAttempts, 1);						//set max tries
		adminMsg.putInt(MQe.Msg_Style, MQe.Msg_Style_Request);					//need a reply
		adminMsg.putAscii(MQe.Msg_ReplyToQMgr, thisQMgrName);					//reply queue manager
		adminMsg.putAscii(MQe.Msg_ReplyToQ, MQe.Admin_Reply_Queue_Name);		//reply queue

		//add unique reference
		byte[] adminKey = MQe.longToByte(System.currentTimeMillis());			//generate unique key
		adminMsg.putArrayOfByte(MQe.Msg_CorrelID, adminKey);					//add key

		//add update command
		adminMsg.putInt(MQeAdminMsg.Admin_Action, MQeAdminMsg.Action_Update);

		//add command parameters
		MQeFields parms = new MQeFields();										//new parms object
		parms.putAscii(MQeAdminMsg.Admin_Name, targetQMgrName);					//admin object
		parms.putAscii(MQeAdminMsg.Admin_Class,
				"com.ibm.MQeQueueManager");										//object class
		parms.putLong(MQeQueueManagerAdminMsg.QMgr_ChnlTimeout,
				1000000L);														//new timeout value
		adminMsg.putFields(MQeAdminMsg.Admin_Parms, parms);						//add parms

		//send admin message
		qMgr.putMessage(targetQMgrName, MQe.Admin_Queue_Name, adminMsg , null, 0);

		//inform that admin message sent
		System.out.println("Property set admin message sent");
		
		//getting the reply
		
		//create a filter
		MQeFields msgFilter = new MQeFields();									//new filter
		msgFilter.putArrayOfByte(MQe.Msg_CorrelID, adminKey);					//add key

		//wait for reply
		int waitTime = 10000;													//wait 10 secs
		MQeAdminMsg adminReply = (MQeAdminMsg) qMgr.waitForMessage(thisQMgrName,
			MQe.Admin_Reply_Queue_Name, msgFilter, null, 0, waitTime);			//get reply
		
		//inform that reply received
		if (adminReply != null) System.out.println("Reply received");
		
		//report on success
		byte returnCode = adminReply.getByte(MQeAdminMsg.Admin_RC);
		if (returnCode == MQeAdminMsg.RC_Success)
			System.out.println("Success");
		else System.out.println("Errors occured");
	}
	
	//
	//start an existing configured queue manager 
	//environmental parameters loaded from a .ini file (or programatically if source edited)
	//this will start the queue manager myClientQMgr created by MQe_Explorer
	//
	private void startClientQMgr() throws Exception
	{
		//initialize strings
		String filename =
			"C:\\Program Files\\MQe\\Java\\mqe_explorer\\myClientQMgr.ini";		//file path
		
		//load .ini file into MQeFields object
		MQeFields environment = MQeQueueManagerUtils.loadConfigFile(filename);
		
		// or create environment variable programmatically ...
		//MQeFields environment = createClientEnvironment();

		//process class aliases  [Alias] stanza (or equivalent)
		MQeQueueManagerUtils.processAlias(environment);

		//process pre-loads  [PreLoad] stanza (or equivalent)
		MQeQueueManagerUtils.processPreLoad(environment);

		//process permissions  [Permission] stanza (or equivalent)
		MQeQueueManagerUtils.processPermission(environment);
		
		//start the queue manager
		MQeQueueManager qMgr = MQeQueueManagerUtils.processQueueManager(environment,
				new Hashtable());

		//confirm that queue manager started
		String thisQMgrName = qMgr.getName();									//local qMgr name
		System.out.println("Queue manager started: " + thisQMgrName);
	}
	
	//
	//start an existing configured queue manager 
	//environmental parameters loaded from a .ini file (or programatically if source edited)
	//this will start the queue manager myGatewayQMgr created by MQe_Explorer
	//
	private void startGatewayQMgr() throws Exception
	{
		//initialize strings
		String filename =
			"C:\\Program Files\\MQe\\Java\\mqe_explorer\\myGatewayQMgr.ini";	//file path
		
		//load .ini file into MQeFields object
		MQeFields environment = MQeQueueManagerUtils.loadConfigFile(filename);
		
		// or create environment variable programmatically ...
		//MQeFields environment = createGatewayEnvironment();

		//process class aliases  [Alias] stanza (or equivalent)
		MQeQueueManagerUtils.processAlias(environment);

		//process pre-loads  [PreLoad] stanza (or equivalent)
		MQeQueueManagerUtils.processPreLoad(environment);

		//process permissions  [Permission] stanza (or equivalent)
		MQeQueueManagerUtils.processPermission(environment);
		
		//process channel manager  [ChannelManager] stanza
		MQeChannelManager localChannelManager = 
			MQeQueueManagerUtils.processChannelManager(environment);
		if (localChannelManager != null)
			System.out.println("Channel manager started");

		//start the queue manager
		MQeQueueManager qMgr =
			MQeQueueManagerUtils.processQueueManager(environment,
			localChannelManager.getGlobalHashtable( ));

		//process the client/server channel listener
		localChannelListener =
			MQeQueueManagerUtils.processListener(environment,
			localChannelManager);
		if (localChannelListener != null)
			System.out.println("Channel listener started");
		
		//start the bridges object
		localBridges = new MQeMQBridges();
		localBridges.activate(environment);
		if (localBridges != null)
			System.out.println("Bridges object active");

		//confirm that queue manager started
		String thisQMgrName = qMgr.getName();									//local qMgr name
		System.out.println("Queue manager started: " + thisQMgrName);
	}
	
	//
	//start an existing configured queue manager 
	//environmental parameters loaded from a .ini file (or programatically if source edited)
	//this will start the queue manager myPeerQMgr created by MQe_Explorer
	//
	private void startPeerQMgr() throws Exception
	{
		//initialize strings
		String filename =
			"C:\\Program Files\\MQe\\Java\\mqe_explorer\\myPeerQMgr.ini";		//file path
		
		//load .ini file into MQeFields object
		MQeFields environment = MQeQueueManagerUtils.loadConfigFile(filename);
		
		// or create environment variable programmatically ...
		//MQeFields environment = createPeerEnvironment();

		//process class aliases  [Alias] stanza (or equivalent)
		MQeQueueManagerUtils.processAlias(environment);

		//process pre-loads  [PreLoad] stanza (or equivalent)
		MQeQueueManagerUtils.processPreLoad(environment);

		//process permissions  [Permission] stanza (or equivalent)
		MQeQueueManagerUtils.processPermission(environment);
		
		//start the queue manager
		MQeQueueManager qMgr = MQeQueueManagerUtils.processQueueManager(environment, null);

		//confirm that queue manager started
		String thisQMgrName = qMgr.getName();									//local qMgr name
		System.out.println("Queue manager started: " + thisQMgrName);
	}
	
	//
	//start an existing configured queue manager 
	//environmental parameters loaded from a .ini file (or programatically if source edited)
	//this will start the queue manager myServerQMgr created by MQe_Explorer
	//
	private void startServerQMgr() throws Exception
	{
		//initialize strings
		String filename =
			"C:\\Program Files\\MQe\\Java\\mqe_explorer\\myServerQMgr.ini";		//file path
		
		//load .ini file into MQeFields object
		MQeFields environment = MQeQueueManagerUtils.loadConfigFile(filename);
		
		// or create environment variable programmatically ...
		//MQeFields environment = createServerEnvironment();

		//process class aliases  [Alias] stanza (or equivalent)
		MQeQueueManagerUtils.processAlias(environment);

		//process pre-loads  [PreLoad] stanza (or equivalent)
		MQeQueueManagerUtils.processPreLoad(environment);

		//process permissions  [Permission] stanza (or equivalent)
		MQeQueueManagerUtils.processPermission(environment);
		
		//process channel manager  [ChannelManager] stanza
		MQeChannelManager localChannelManager = 
			MQeQueueManagerUtils.processChannelManager(environment);
		if (localChannelManager != null)
			System.out.println("Channel manager started");

		//start the queue manager
		MQeQueueManager qMgr =
			MQeQueueManagerUtils.processQueueManager(environment,
			localChannelManager.getGlobalHashtable());

		//process the client/server channel listener
		localChannelListener =
			MQeQueueManagerUtils.processListener(environment,
			localChannelManager);
		if (localChannelListener != null)
			System.out.println("Channel listener started");
		
		//confirm that queue manager started
		String thisQMgrName = qMgr.getName();									//local qMgr name
		System.out.println("Queue manager started: " + thisQMgrName);
	}
	
	//
	//stops a client queue manager
	//
	private void stopClientQMgr() throws Exception
	{
		//get addressability to the local queue manager
		MQeQueueManager qMgr = MQeQueueManager.getReference(null);
		
		//close the queue manager
		qMgr.close();
		
		//issue message
		System.out.println("Queue manager closed");	
	}
	
	//
	//stops a gateway queue manager
	//
	private void stopGatewayQMgr() throws Exception
	{
		//close the listener
		localChannelListener.stop();
		
		//close the bridges object
		localBridges.close();

		//close the queue manager
		MQeQueueManager qMgr = MQeQueueManager.getReference(null);
		qMgr.close();

		//issue message
		System.out.println("Queue manager closed");	
	}
	
	//
	//stops a peer queue manager
	//
	private void stopPeerQMgr() throws Exception
	{
		//get addressability to the local queue manager
		MQeQueueManager qMgr = MQeQueueManager.getReference(null);
		
		//close the queue manager
		qMgr.close();
		
		//issue message
		System.out.println("Queue manager closed");	
	}
	
	//
	//stops a server queue manager
	//
	private void stopServerQMgr() throws Exception
	{
		//close the listener
		localChannelListener.stop();

		//close the queue manager
		MQeQueueManager qMgr = MQeQueueManager.getReference(null);
		qMgr.close();

		//issue message
		System.out.println("Queue manager closed");	
	}
}
